pub struct Input { /* private fields */ }Expand description
The input buffer with cursor support.
Example:
use tui_input::Input;
let input: Input = "Hello World".into();
assert_eq!(input.cursor(), 11);
assert_eq!(input.to_string(), "Hello World");Implementations
Sourceimpl Input
impl Input
Sourcepub fn new(value: String) -> Self
pub fn new(value: String) -> Self
Initialize a new instance with a given value Cursor will be set to the given value’s length.
Sourcepub fn with_value(self, value: String) -> Self
pub fn with_value(self, value: String) -> Self
Set the value manually. Cursor will be set to the given value’s length.
Sourcepub fn with_cursor(self, cursor: usize) -> Self
pub fn with_cursor(self, cursor: usize) -> Self
Set the cursor manually. If the input is larger than the value length, it’ll be auto adjusted.
pub fn reset(&mut self)
pub fn value_and_reset(&mut self) -> String
Sourcepub fn handle(&mut self, req: InputRequest) -> InputResponse
pub fn handle(&mut self, req: InputRequest) -> InputResponse
Handle request and emit response.
Sourcepub fn cursor(&self) -> usize
pub fn cursor(&self) -> usize
Returns the number of codepoints preceding the cursor. Movement
and deletion operations step one grapheme at a time, so a single
InputRequest::GoToNextChar or InputRequest::DeletePrevChar
may change this count by more than one.
Sourcepub fn visual_cursor(&self) -> usize
pub fn visual_cursor(&self) -> usize
Returns the cursor’s position in display columns (per
unicode-width).
Sourcepub fn visual_scroll(&self, width: usize) -> usize
pub fn visual_scroll(&self, width: usize) -> usize
Get the scroll position with account for multispace characters.