Struct tui_input::StateChanged
source · pub struct StateChanged {
pub value: bool,
pub cursor: bool,
}Fields
value: boolcursor: boolTrait Implementations
sourceimpl Clone for StateChanged
impl Clone for StateChanged
sourcefn clone(&self) -> StateChanged
fn clone(&self) -> StateChanged
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for StateChanged
impl Debug for StateChanged
sourceimpl Hash for StateChanged
impl Hash for StateChanged
sourceimpl PartialEq<StateChanged> for StateChanged
impl PartialEq<StateChanged> for StateChanged
sourcefn eq(&self, other: &StateChanged) -> bool
fn eq(&self, other: &StateChanged) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<StateChanged> for StateChanged
impl PartialOrd<StateChanged> for StateChanged
sourcefn partial_cmp(&self, other: &StateChanged) -> Option<Ordering>
fn partial_cmp(&self, other: &StateChanged) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for StateChanged
impl Eq for StateChanged
impl StructuralEq for StateChanged
impl StructuralPartialEq for StateChanged