Enum tui_input::InputRequest
source · pub enum InputRequest {
}Expand description
Input requests are used to change the input state.
Different backends can be used to convert events into requests.
Variants
SetCursor(usize)
InsertChar(char)
GoToPrevChar
GoToNextChar
GoToPrevWord
GoToNextWord
GoToStart
GoToEnd
DeletePrevChar
DeleteNextChar
DeletePrevWord
DeleteNextWord
DeleteLine
DeleteTillEnd