Struct tui_input::Input

source ·
pub struct Input { /* private fields */ }
The input buffer with cursor support.

Example:

use tui_input::Input;

let input: Input = "Hello World".into();

assert_eq!(input.cursor(), 11);
assert_eq!(input.to_string(), "Hello World");

Implementations

source

impl Input

source

pub fn new(value: String) -> Self

Initialize a new instance with a given value Cursor will be set to the given value’s length.

source

pub fn with_value(self, value: String) -> Self

Set the value manually. Cursor will be set to the given value’s length.

source

pub fn with_cursor(self, cursor: usize) -> Self

Set the cursor manually. If the input is larger than the value length, it’ll be auto adjusted.

source

pub fn reset(&mut self)

source

pub fn handle(&mut self, req: InputRequest) -> InputResponse

Handle request and emit response.

source

pub fn value(&self) -> &str

Get a reference to the current value.

Examples found in repository?
examples/crossterm_input.rs (line 21)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
fn main() -> Result<()> {
    enable_raw_mode()?;
    let stdout = stdout();
    let mut stdout = stdout.lock();
    execute!(stdout, Hide, EnterAlternateScreen, EnableMouseCapture)?;

    let mut input: Input = "Hello ".into();
    backend::write(&mut stdout, input.value(), input.cursor(), (0, 0), 15)?;
    stdout.flush()?;

    loop {
        let event = read()?;

        if let Event::Key(KeyEvent { code, .. }) = event {
            match code {
                KeyCode::Esc | KeyCode::Enter => {
                    break;
                }
                _ => {
                    if input.handle_event(&event).is_some() {
                        backend::write(
                            &mut stdout,
                            input.value(),
                            input.cursor(),
                            (0, 0),
                            15,
                        )?;
                        stdout.flush()?;
                    }
                }
            }
        }
    }

    execute!(stdout, Show, LeaveAlternateScreen, DisableMouseCapture)?;
    disable_raw_mode()?;
    println!("{}", input);
    Ok(())
}
source

pub fn cursor(&self) -> usize

Get the currect cursor placement.

Examples found in repository?
examples/crossterm_input.rs (line 21)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
fn main() -> Result<()> {
    enable_raw_mode()?;
    let stdout = stdout();
    let mut stdout = stdout.lock();
    execute!(stdout, Hide, EnterAlternateScreen, EnableMouseCapture)?;

    let mut input: Input = "Hello ".into();
    backend::write(&mut stdout, input.value(), input.cursor(), (0, 0), 15)?;
    stdout.flush()?;

    loop {
        let event = read()?;

        if let Event::Key(KeyEvent { code, .. }) = event {
            match code {
                KeyCode::Esc | KeyCode::Enter => {
                    break;
                }
                _ => {
                    if input.handle_event(&event).is_some() {
                        backend::write(
                            &mut stdout,
                            input.value(),
                            input.cursor(),
                            (0, 0),
                            15,
                        )?;
                        stdout.flush()?;
                    }
                }
            }
        }
    }

    execute!(stdout, Show, LeaveAlternateScreen, DisableMouseCapture)?;
    disable_raw_mode()?;
    println!("{}", input);
    Ok(())
}
source

pub fn visual_cursor(&self) -> usize

Get the current cursor position with account for multispace characters.

source

pub fn visual_scroll(&self, width: usize) -> usize

Get the scroll position with account for multispace characters.